NetworkState enum

网络状态

Inheritance
Available extensions

Values

unknown → const NetworkState

未知

connected → const NetworkState

已连接

wifi → const NetworkState

WiFi 连接

mobile → const NetworkState

移动数据连接

disconnected → const NetworkState

断开连接

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NetworkState>
A constant List of the values in this enum, in order of their declaration.