BatchSyncResult class
批量同步结果
Constructors
-
BatchSyncResult({required SyncResultStatus status, required int totalFiles, required int successCount, required int failedCount, required int skippedCount, required List<
FileSyncResult> fileResults, required DateTime startTime, DateTime? endTime, String? errorMessage}) -
const
-
BatchSyncResult.fromMap(Map<
String, dynamic> map) -
factory
Properties
- durationMs → int?
-
总耗时(毫秒)
no setter
- endTime → DateTime?
-
结束时间
final
- errorMessage → String?
-
错误信息
final
- failedCount → int
-
失败数
final
-
fileResults
→ List<
FileSyncResult> -
文件结果列表
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skippedCount → int
-
跳过数
final
- startTime → DateTime
-
开始时间
final
- status → SyncResultStatus
-
结果状态
final
- successCount → int
-
成功数
final
- successRate → double
-
成功率
no setter
- totalFiles → int
-
总文件数
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited